# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr
from marqeta_client.models.address_request_model import AddressRequestModel
from marqeta_client.models.beneficial_owner_request import BeneficialOwnerRequest
from marqeta_client.models.business_incorporation import BusinessIncorporation
from marqeta_client.models.business_proprietor import BusinessProprietor
from marqeta_client.models.identification_request_model import IdentificationRequestModel
from marqeta_client.models.primary_contact_info_model import PrimaryContactInfoModel

class BusinessCardholder(BaseModel):
    """
    BusinessCardholder
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    active: Optional[StrictBool] = True
    notes: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    ip_address: Optional[constr(strict=True, max_length=39, min_length=0)] = None
    password: Optional[constr(strict=True, max_length=255, min_length=1)] = Field(None, description="Strong password required")
    phone: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    metadata: Optional[Dict[str, StrictStr]] = None
    account_holder_group_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    identifications: Optional[conlist(IdentificationRequestModel)] = None
    business_name_legal: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    business_name_dba: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    office_location: Optional[AddressRequestModel] = None
    in_current_location_since: Optional[datetime] = None
    website: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    date_established: Optional[datetime] = None
    general_business_description: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    history: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    business_type: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    international_office_locations: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    taxpayer_id: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    duns_number: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    primary_contact: Optional[PrimaryContactInfoModel] = None
    incorporation: Optional[BusinessIncorporation] = None
    proprietor_or_officer: Optional[BusinessProprietor] = None
    beneficial_owner1: Optional[BeneficialOwnerRequest] = None
    beneficial_owner2: Optional[BeneficialOwnerRequest] = None
    beneficial_owner3: Optional[BeneficialOwnerRequest] = None
    beneficial_owner4: Optional[BeneficialOwnerRequest] = None
    attester_name: Optional[constr(strict=True, max_length=64, min_length=0)] = None
    attestation_consent: Optional[StrictBool] = False
    attester_title: Optional[constr(strict=True, max_length=64, min_length=0)] = None
    attestation_date: Optional[datetime] = Field(None, description="YYYY-MM-DDThh:mm:ssZ")
    proprietor_is_beneficial_owner: Optional[StrictBool] = False
    __properties = ["token", "active", "notes", "ip_address", "password", "phone", "metadata", "account_holder_group_token", "identifications", "business_name_legal", "business_name_dba", "office_location", "in_current_location_since", "website", "date_established", "general_business_description", "history", "business_type", "international_office_locations", "taxpayer_id", "duns_number", "primary_contact", "incorporation", "proprietor_or_officer", "beneficial_owner1", "beneficial_owner2", "beneficial_owner3", "beneficial_owner4", "attester_name", "attestation_consent", "attester_title", "attestation_date", "proprietor_is_beneficial_owner"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessCardholder:
        """Create an instance of BusinessCardholder from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in identifications (list)
        _items = []
        if self.identifications:
            for _item in self.identifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['identifications'] = _items
        # override the default output from pydantic by calling `to_dict()` of office_location
        if self.office_location:
            _dict['office_location'] = self.office_location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of primary_contact
        if self.primary_contact:
            _dict['primary_contact'] = self.primary_contact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of incorporation
        if self.incorporation:
            _dict['incorporation'] = self.incorporation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of proprietor_or_officer
        if self.proprietor_or_officer:
            _dict['proprietor_or_officer'] = self.proprietor_or_officer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of beneficial_owner1
        if self.beneficial_owner1:
            _dict['beneficial_owner1'] = self.beneficial_owner1.to_dict()
        # override the default output from pydantic by calling `to_dict()` of beneficial_owner2
        if self.beneficial_owner2:
            _dict['beneficial_owner2'] = self.beneficial_owner2.to_dict()
        # override the default output from pydantic by calling `to_dict()` of beneficial_owner3
        if self.beneficial_owner3:
            _dict['beneficial_owner3'] = self.beneficial_owner3.to_dict()
        # override the default output from pydantic by calling `to_dict()` of beneficial_owner4
        if self.beneficial_owner4:
            _dict['beneficial_owner4'] = self.beneficial_owner4.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessCardholder:
        """Create an instance of BusinessCardholder from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BusinessCardholder.parse_obj(obj)

        _obj = BusinessCardholder.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "notes": obj.get("notes"),
            "ip_address": obj.get("ip_address"),
            "password": obj.get("password"),
            "phone": obj.get("phone"),
            "metadata": obj.get("metadata"),
            "account_holder_group_token": obj.get("account_holder_group_token"),
            "identifications": [IdentificationRequestModel.from_dict(_item) for _item in obj.get("identifications")] if obj.get("identifications") is not None else None,
            "business_name_legal": obj.get("business_name_legal"),
            "business_name_dba": obj.get("business_name_dba"),
            "office_location": AddressRequestModel.from_dict(obj.get("office_location")) if obj.get("office_location") is not None else None,
            "in_current_location_since": obj.get("in_current_location_since"),
            "website": obj.get("website"),
            "date_established": obj.get("date_established"),
            "general_business_description": obj.get("general_business_description"),
            "history": obj.get("history"),
            "business_type": obj.get("business_type"),
            "international_office_locations": obj.get("international_office_locations"),
            "taxpayer_id": obj.get("taxpayer_id"),
            "duns_number": obj.get("duns_number"),
            "primary_contact": PrimaryContactInfoModel.from_dict(obj.get("primary_contact")) if obj.get("primary_contact") is not None else None,
            "incorporation": BusinessIncorporation.from_dict(obj.get("incorporation")) if obj.get("incorporation") is not None else None,
            "proprietor_or_officer": BusinessProprietor.from_dict(obj.get("proprietor_or_officer")) if obj.get("proprietor_or_officer") is not None else None,
            "beneficial_owner1": BeneficialOwnerRequest.from_dict(obj.get("beneficial_owner1")) if obj.get("beneficial_owner1") is not None else None,
            "beneficial_owner2": BeneficialOwnerRequest.from_dict(obj.get("beneficial_owner2")) if obj.get("beneficial_owner2") is not None else None,
            "beneficial_owner3": BeneficialOwnerRequest.from_dict(obj.get("beneficial_owner3")) if obj.get("beneficial_owner3") is not None else None,
            "beneficial_owner4": BeneficialOwnerRequest.from_dict(obj.get("beneficial_owner4")) if obj.get("beneficial_owner4") is not None else None,
            "attester_name": obj.get("attester_name"),
            "attestation_consent": obj.get("attestation_consent") if obj.get("attestation_consent") is not None else False,
            "attester_title": obj.get("attester_title"),
            "attestation_date": obj.get("attestation_date"),
            "proprietor_is_beneficial_owner": obj.get("proprietor_is_beneficial_owner") if obj.get("proprietor_is_beneficial_owner") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class NetworkFeeModel(BaseModel):
    """
    NetworkFeeModel
    """
    type: Optional[StrictStr] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    credit_debit: Optional[StrictStr] = Field(None, description="C = credit; D = debit")
    __properties = ["type", "amount", "credit_debit"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ISSUER_FEE', 'SWITCH_FEE', 'PINDEBIT_ASSOC_FEE', 'ACQUIRER_FEE', 'INTERCHANGE_FEE', 'CUR_CONV_CARDHOLDER_FEE', 'CUR_CONV_ISSUER_FEE', 'CROSS_BORDER_ISSUER_FEE'):
            raise ValueError("must be one of enum values ('ISSUER_FEE', 'SWITCH_FEE', 'PINDEBIT_ASSOC_FEE', 'ACQUIRER_FEE', 'INTERCHANGE_FEE', 'CUR_CONV_CARDHOLDER_FEE', 'CUR_CONV_ISSUER_FEE', 'CROSS_BORDER_ISSUER_FEE')")
        return v

    @validator('credit_debit')
    def credit_debit_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('C', 'D'):
            raise ValueError("must be one of enum values ('C', 'D')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NetworkFeeModel:
        """Create an instance of NetworkFeeModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NetworkFeeModel:
        """Create an instance of NetworkFeeModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return NetworkFeeModel.parse_obj(obj)

        _obj = NetworkFeeModel.parse_obj({
            "type": obj.get("type"),
            "amount": obj.get("amount"),
            "credit_debit": obj.get("credit_debit")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictStr, constr, validator

class DigitalWalletAndroidPayProvisionRequest(BaseModel):
    """
    DigitalWalletAndroidPayProvisionRequest
    """
    card_token: constr(strict=True, max_length=36, min_length=1) = ...
    device_type: StrictStr = ...
    provisioning_app_version: constr(strict=True, max_length=50, min_length=1) = ...
    wallet_account_id: constr(strict=True, max_length=50, min_length=1) = ...
    device_id: constr(strict=True, max_length=24, min_length=1) = ...
    __properties = ["card_token", "device_type", "provisioning_app_version", "wallet_account_id", "device_id"]

    @validator('device_type')
    def device_type_validate_enum(cls, v):
        if v not in ('MOBILE_PHONE', 'WATCH', 'TABLET'):
            raise ValueError("must be one of enum values ('MOBILE_PHONE', 'WATCH', 'TABLET')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletAndroidPayProvisionRequest:
        """Create an instance of DigitalWalletAndroidPayProvisionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletAndroidPayProvisionRequest:
        """Create an instance of DigitalWalletAndroidPayProvisionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletAndroidPayProvisionRequest.parse_obj(obj)

        _obj = DigitalWalletAndroidPayProvisionRequest.parse_obj({
            "card_token": obj.get("card_token"),
            "device_type": obj.get("device_type"),
            "provisioning_app_version": obj.get("provisioning_app_version"),
            "wallet_account_id": obj.get("wallet_account_id"),
            "device_id": obj.get("device_id")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr

from typing import Optional

from marqeta_client.models.transaction_model import TransactionModel
from marqeta_client.models.transaction_model_list_response import TransactionModelListResponse

from marqeta_client.api_client import ApiClient
from marqeta_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TransactionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_transactions(self, count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, user_token : Annotated[Optional[StrictStr], Field(description="User token")] = None, business_token : Annotated[Optional[StrictStr], Field(description="Business token")] = None, acting_user_token : Annotated[Optional[StrictStr], Field(description="Acting user token")] = None, card_token : Annotated[Optional[StrictStr], Field(description="Card token")] = None, merchant_token : Annotated[Optional[StrictStr], Field(description="Merchant token")] = None, campaign_token : Annotated[Optional[StrictStr], Field(description="Campaign token")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | DECLINED | ERROR | ALL")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, start_identifier : Annotated[Optional[StrictInt], Field(description="Start identifier")] = None, **kwargs) -> TransactionModelListResponse:  # noqa: E501
        """Returns transactions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions(count, start_index, fields, sort_by, start_date, end_date, type, user_token, business_token, acting_user_token, card_token, merchant_token, campaign_token, state, version, verbose, start_identifier, async_req=True)
        >>> result = thread.get()

        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param user_token: User token
        :type user_token: str
        :param business_token: Business token
        :type business_token: str
        :param acting_user_token: Acting user token
        :type acting_user_token: str
        :param card_token: Card token
        :type card_token: str
        :param merchant_token: Merchant token
        :type merchant_token: str
        :param campaign_token: Campaign token
        :type campaign_token: str
        :param state: Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | DECLINED | ERROR | ALL
        :type state: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param start_identifier: Start identifier
        :type start_identifier: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TransactionModelListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_transactions_with_http_info(count, start_index, fields, sort_by, start_date, end_date, type, user_token, business_token, acting_user_token, card_token, merchant_token, campaign_token, state, version, verbose, start_identifier, **kwargs)  # noqa: E501

    @validate_arguments
    def get_transactions_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, user_token : Annotated[Optional[StrictStr], Field(description="User token")] = None, business_token : Annotated[Optional[StrictStr], Field(description="Business token")] = None, acting_user_token : Annotated[Optional[StrictStr], Field(description="Acting user token")] = None, card_token : Annotated[Optional[StrictStr], Field(description="Card token")] = None, merchant_token : Annotated[Optional[StrictStr], Field(description="Merchant token")] = None, campaign_token : Annotated[Optional[StrictStr], Field(description="Campaign token")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | DECLINED | ERROR | ALL")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, start_identifier : Annotated[Optional[StrictInt], Field(description="Start identifier")] = None, **kwargs):  # noqa: E501
        """Returns transactions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_with_http_info(count, start_index, fields, sort_by, start_date, end_date, type, user_token, business_token, acting_user_token, card_token, merchant_token, campaign_token, state, version, verbose, start_identifier, async_req=True)
        >>> result = thread.get()

        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param user_token: User token
        :type user_token: str
        :param business_token: Business token
        :type business_token: str
        :param acting_user_token: Acting user token
        :type acting_user_token: str
        :param card_token: Card token
        :type card_token: str
        :param merchant_token: Merchant token
        :type merchant_token: str
        :param campaign_token: Campaign token
        :type campaign_token: str
        :param state: Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | DECLINED | ERROR | ALL
        :type state: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param start_identifier: Start identifier
        :type start_identifier: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TransactionModelListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'fields',
            'sort_by',
            'start_date',
            'end_date',
            'type',
            'user_token',
            'business_token',
            'acting_user_token',
            'card_token',
            'merchant_token',
            'campaign_token',
            'state',
            'version',
            'verbose',
            'start_identifier'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transactions" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by'].value))

        if _params.get('start_date') is not None:  # noqa: E501
            _query_params.append(('start_date', _params['start_date']))

        if _params.get('end_date') is not None:  # noqa: E501
            _query_params.append(('end_date', _params['end_date']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('user_token') is not None:  # noqa: E501
            _query_params.append(('user_token', _params['user_token']))

        if _params.get('business_token') is not None:  # noqa: E501
            _query_params.append(('business_token', _params['business_token']))

        if _params.get('acting_user_token') is not None:  # noqa: E501
            _query_params.append(('acting_user_token', _params['acting_user_token']))

        if _params.get('card_token') is not None:  # noqa: E501
            _query_params.append(('card_token', _params['card_token']))

        if _params.get('merchant_token') is not None:  # noqa: E501
            _query_params.append(('merchant_token', _params['merchant_token']))

        if _params.get('campaign_token') is not None:  # noqa: E501
            _query_params.append(('campaign_token', _params['campaign_token']))

        if _params.get('state') is not None:  # noqa: E501
            _query_params.append(('state', _params['state']))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        if _params.get('verbose') is not None:  # noqa: E501
            _query_params.append(('verbose', _params['verbose']))

        if _params.get('start_identifier') is not None:  # noqa: E501
            _query_params.append(('start_identifier', _params['start_identifier']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "TransactionModelListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/transactions', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_transactions_fundingsource_fundingsourcetoken(self, funding_source_token : Annotated[StrictStr, Field(..., description="Funding account token")], count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, polarity : Annotated[Optional[StrictStr], Field(description="Type of transactions to retrieve: CREDIT or DEBIT")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs) -> TransactionModelListResponse:  # noqa: E501
        """Returns transactions for a specific funding account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_fundingsource_fundingsourcetoken(funding_source_token, count, start_index, fields, sort_by, start_date, end_date, type, polarity, version, verbose, async_req=True)
        >>> result = thread.get()

        :param funding_source_token: Funding account token (required)
        :type funding_source_token: str
        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param polarity: Type of transactions to retrieve: CREDIT or DEBIT
        :type polarity: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TransactionModelListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_transactions_fundingsource_fundingsourcetoken_with_http_info(funding_source_token, count, start_index, fields, sort_by, start_date, end_date, type, polarity, version, verbose, **kwargs)  # noqa: E501

    @validate_arguments
    def get_transactions_fundingsource_fundingsourcetoken_with_http_info(self, funding_source_token : Annotated[StrictStr, Field(..., description="Funding account token")], count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, polarity : Annotated[Optional[StrictStr], Field(description="Type of transactions to retrieve: CREDIT or DEBIT")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs):  # noqa: E501
        """Returns transactions for a specific funding account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_fundingsource_fundingsourcetoken_with_http_info(funding_source_token, count, start_index, fields, sort_by, start_date, end_date, type, polarity, version, verbose, async_req=True)
        >>> result = thread.get()

        :param funding_source_token: Funding account token (required)
        :type funding_source_token: str
        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param polarity: Type of transactions to retrieve: CREDIT or DEBIT
        :type polarity: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TransactionModelListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'funding_source_token',
            'count',
            'start_index',
            'fields',
            'sort_by',
            'start_date',
            'end_date',
            'type',
            'polarity',
            'version',
            'verbose'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transactions_fundingsource_fundingsourcetoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['funding_source_token']:
            _path_params['funding_source_token'] = _params['funding_source_token']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by'].value))

        if _params.get('start_date') is not None:  # noqa: E501
            _query_params.append(('start_date', _params['start_date']))

        if _params.get('end_date') is not None:  # noqa: E501
            _query_params.append(('end_date', _params['end_date']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('polarity') is not None:  # noqa: E501
            _query_params.append(('polarity', _params['polarity'].value))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        if _params.get('verbose') is not None:  # noqa: E501
            _query_params.append(('verbose', _params['verbose']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "TransactionModelListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/transactions/fundingsource/{funding_source_token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_transactions_token(self, token : Annotated[StrictStr, Field(..., description="Transaction token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs) -> TransactionModel:  # noqa: E501
        """Returns a transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_token(token, fields, version, verbose, async_req=True)
        >>> result = thread.get()

        :param token: Transaction token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TransactionModel
        """
        kwargs['_return_http_data_only'] = True
        return self.get_transactions_token_with_http_info(token, fields, version, verbose, **kwargs)  # noqa: E501

    @validate_arguments
    def get_transactions_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Transaction token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs):  # noqa: E501
        """Returns a transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_token_with_http_info(token, fields, version, verbose, async_req=True)
        >>> result = thread.get()

        :param token: Transaction token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TransactionModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'fields',
            'version',
            'verbose'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transactions_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        if _params.get('verbose') is not None:  # noqa: E501
            _query_params.append(('verbose', _params['verbose']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "TransactionModel",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/transactions/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_transactions_token_related(self, token : Annotated[StrictStr, Field(..., description="Transaction token")], count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | ALL")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs) -> TransactionModelListResponse:  # noqa: E501
        """Returns related transactions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_token_related(token, count, start_index, fields, sort_by, start_date, end_date, type, state, version, verbose, async_req=True)
        >>> result = thread.get()

        :param token: Transaction token (required)
        :type token: str
        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param state: Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | ALL
        :type state: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TransactionModelListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_transactions_token_related_with_http_info(token, count, start_index, fields, sort_by, start_date, end_date, type, state, version, verbose, **kwargs)  # noqa: E501

    @validate_arguments
    def get_transactions_token_related_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Transaction token")], count : Annotated[Optional[StrictInt], Field(description="Number of transactions to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)")] = None, type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction types to include")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | ALL")] = None, version : Optional[StrictStr] = None, verbose : Optional[StrictBool] = None, **kwargs):  # noqa: E501
        """Returns related transactions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transactions_token_related_with_http_info(token, count, start_index, fields, sort_by, start_date, end_date, type, state, version, verbose, async_req=True)
        >>> result = thread.get()

        :param token: Transaction token (required)
        :type token: str
        :param count: Number of transactions to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd | yyyy-MM-ddTHH:mm:ss.SS)
        :type end_date: str
        :param type: Comma-delimited list of transaction types to include
        :type type: str
        :param state: Comma-delimited list of transaction states to display e.g. PENDING | CLEARED | COMPLETION | ALL
        :type state: str
        :param version:
        :type version: str
        :param verbose:
        :type verbose: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TransactionModelListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'count',
            'start_index',
            'fields',
            'sort_by',
            'start_date',
            'end_date',
            'type',
            'state',
            'version',
            'verbose'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transactions_token_related" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by'].value))

        if _params.get('start_date') is not None:  # noqa: E501
            _query_params.append(('start_date', _params['start_date']))

        if _params.get('end_date') is not None:  # noqa: E501
            _query_params.append(('end_date', _params['end_date']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('state') is not None:  # noqa: E501
            _query_params.append(('state', _params['state']))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        if _params.get('verbose') is not None:  # noqa: E501
            _query_params.append(('verbose', _params['verbose']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "TransactionModelListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/transactions/{token}/related', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, conlist
from marqeta_client.models.cardholder_balance import CardholderBalance
from marqeta_client.models.link import Link

class CardholderBalances(BaseModel):
    """
    CardholderBalances
    """
    gpa: CardholderBalance = ...
    links: conlist(Link, unique_items=True) = ...
    __properties = ["gpa", "links"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardholderBalances:
        """Create an instance of CardholderBalances from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gpa
        if self.gpa:
            _dict['gpa'] = self.gpa.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardholderBalances:
        """Create an instance of CardholderBalances from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardholderBalances.parse_obj(obj)

        _obj = CardholderBalances.parse_obj({
            "gpa": CardholderBalance.from_dict(obj.get("gpa")) if obj.get("gpa") is not None else None,
            "links": [Link.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from marqeta_client.models.result import Result

class KycResponse(BaseModel):
    """
    KycResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    token: Optional[StrictStr] = None
    user_token: Optional[StrictStr] = None
    business_token: Optional[StrictStr] = None
    result: Optional[Result] = None
    manual_override: Optional[StrictBool] = False
    notes: Optional[StrictStr] = None
    reference_id: Optional[StrictStr] = None
    __properties = ["created_time", "last_modified_time", "token", "user_token", "business_token", "result", "manual_override", "notes", "reference_id"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> KycResponse:
        """Create an instance of KycResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "manual_override",
                            "notes",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> KycResponse:
        """Create an instance of KycResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return KycResponse.parse_obj(obj)

        _obj = KycResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "result": Result.from_dict(obj.get("result")) if obj.get("result") is not None else None,
            "manual_override": obj.get("manual_override") if obj.get("manual_override") is not None else False,
            "notes": obj.get("notes"),
            "reference_id": obj.get("reference_id")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr

class TransactionOptions(BaseModel):
    """
    TransactionOptions
    """
    additional_data: Optional[StrictStr] = None
    database_transaction_timeout: Optional[StrictInt] = None
    transaction_timeout_threshold_seconds: Optional[StrictInt] = None
    pre_auth_time_limit: Optional[StrictStr] = None
    send_expiration_date: Optional[StrictBool] = False
    send_track_data: Optional[StrictBool] = False
    card_expiration_date_yymm: Optional[StrictStr] = None
    encryption_key_id: Optional[StrictStr] = None
    transaction_token: Optional[StrictStr] = None
    is_async: Optional[StrictBool] = False
    __properties = ["additional_data", "database_transaction_timeout", "transaction_timeout_threshold_seconds", "pre_auth_time_limit", "send_expiration_date", "send_track_data", "card_expiration_date_yymm", "encryption_key_id", "transaction_token", "is_async"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionOptions:
        """Create an instance of TransactionOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionOptions:
        """Create an instance of TransactionOptions from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionOptions.parse_obj(obj)

        _obj = TransactionOptions.parse_obj({
            "additional_data": obj.get("additional_data"),
            "database_transaction_timeout": obj.get("database_transaction_timeout"),
            "transaction_timeout_threshold_seconds": obj.get("transaction_timeout_threshold_seconds"),
            "pre_auth_time_limit": obj.get("pre_auth_time_limit"),
            "send_expiration_date": obj.get("send_expiration_date") if obj.get("send_expiration_date") is not None else False,
            "send_track_data": obj.get("send_track_data") if obj.get("send_track_data") is not None else False,
            "card_expiration_date_yymm": obj.get("card_expiration_date_yymm"),
            "encryption_key_id": obj.get("encryption_key_id"),
            "transaction_token": obj.get("transaction_token"),
            "is_async": obj.get("is_async") if obj.get("is_async") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from marqeta_client.models.advanced_clearing_request_model import AdvancedClearingRequestModel

class ClearingFileRequest(BaseModel):
    """
    ClearingFileRequest
    """
    transaction_tokens: conlist(AdvancedClearingRequestModel) = Field(..., description="A list of 'clearing_transaction_request' items")
    wait_timeout: Optional[StrictInt] = Field(None, description="Timeout in seconds")
    batch_id: Optional[StrictStr] = Field(None, description="A string representing batch ID")
    clearing_folder: Optional[StrictStr] = None
    encrypt_file: Optional[StrictBool] = None
    create_completion_file: Optional[StrictBool] = None
    settlement_date: Optional[StrictStr] = None
    token_pan: Optional[StrictStr] = None
    __properties = ["transaction_tokens", "wait_timeout", "batch_id", "clearing_folder", "encrypt_file", "create_completion_file", "settlement_date", "token_pan"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClearingFileRequest:
        """Create an instance of ClearingFileRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in transaction_tokens (list)
        _items = []
        if self.transaction_tokens:
            for _item in self.transaction_tokens:
                if _item:
                    _items.append(_item.to_dict())
            _dict['transaction_tokens'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClearingFileRequest:
        """Create an instance of ClearingFileRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ClearingFileRequest.parse_obj(obj)

        _obj = ClearingFileRequest.parse_obj({
            "transaction_tokens": [AdvancedClearingRequestModel.from_dict(_item) for _item in obj.get("transaction_tokens")] if obj.get("transaction_tokens") is not None else None,
            "wait_timeout": obj.get("wait_timeout"),
            "batch_id": obj.get("batch_id"),
            "clearing_folder": obj.get("clearing_folder"),
            "encrypt_file": obj.get("encrypt_file"),
            "create_completion_file": obj.get("create_completion_file"),
            "settlement_date": obj.get("settlement_date"),
            "token_pan": obj.get("token_pan")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr

from typing import Optional

from marqeta_client.models.gpa_unload_list_response import GPAUnloadListResponse
from marqeta_client.models.gpa_request import GpaRequest
from marqeta_client.models.gpa_response import GpaResponse
from marqeta_client.models.gpa_returns import GpaReturns
from marqeta_client.models.unload_request_model import UnloadRequestModel

from marqeta_client.api_client import ApiClient
from marqeta_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class GpaOrdersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_gpaorders_token(self, token : StrictStr, **kwargs) -> GpaResponse:  # noqa: E501
        """Returns a GPA order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_token(token, async_req=True)
        >>> result = thread.get()

        :param token: (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GpaResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_gpaorders_token_with_http_info(token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_gpaorders_token_with_http_info(self, token : StrictStr, **kwargs):  # noqa: E501
        """Returns a GPA order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_token_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param token: (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GpaResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_gpaorders_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "GpaResponse",
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/gpaorders/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_gpaorders_unloads(self, count : Annotated[Optional[StrictInt], Field(description="Number of GPA unloads to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, user_token : Annotated[Optional[StrictStr], Field(description="User token")] = None, business_token : Annotated[Optional[StrictStr], Field(description="Business token")] = None, original_order_token : Annotated[Optional[StrictStr], Field(description="Original order token")] = None, **kwargs) -> GPAUnloadListResponse:  # noqa: E501
        """Lists all GPA returns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_unloads(count, start_index, fields, sort_by, user_token, business_token, original_order_token, async_req=True)
        >>> result = thread.get()

        :param count: Number of GPA unloads to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param user_token: User token
        :type user_token: str
        :param business_token: Business token
        :type business_token: str
        :param original_order_token: Original order token
        :type original_order_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GPAUnloadListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_gpaorders_unloads_with_http_info(count, start_index, fields, sort_by, user_token, business_token, original_order_token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_gpaorders_unloads_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of GPA unloads to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, user_token : Annotated[Optional[StrictStr], Field(description="User token")] = None, business_token : Annotated[Optional[StrictStr], Field(description="Business token")] = None, original_order_token : Annotated[Optional[StrictStr], Field(description="Original order token")] = None, **kwargs):  # noqa: E501
        """Lists all GPA returns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_unloads_with_http_info(count, start_index, fields, sort_by, user_token, business_token, original_order_token, async_req=True)
        >>> result = thread.get()

        :param count: Number of GPA unloads to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param user_token: User token
        :type user_token: str
        :param business_token: Business token
        :type business_token: str
        :param original_order_token: Original order token
        :type original_order_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GPAUnloadListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'fields',
            'sort_by',
            'user_token',
            'business_token',
            'original_order_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_gpaorders_unloads" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        if _params.get('user_token') is not None:  # noqa: E501
            _query_params.append(('user_token', _params['user_token']))

        if _params.get('business_token') is not None:  # noqa: E501
            _query_params.append(('business_token', _params['business_token']))

        if _params.get('original_order_token') is not None:  # noqa: E501
            _query_params.append(('original_order_token', _params['original_order_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "GPAUnloadListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/gpaorders/unloads', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_gpaorders_unloads_unloadtoken(self, unload_token : Annotated[StrictStr, Field(..., description="Unload token")], **kwargs) -> GpaReturns:  # noqa: E501
        """Returns a specific GPA return  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_unloads_unloadtoken(unload_token, async_req=True)
        >>> result = thread.get()

        :param unload_token: Unload token (required)
        :type unload_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GpaReturns
        """
        kwargs['_return_http_data_only'] = True
        return self.get_gpaorders_unloads_unloadtoken_with_http_info(unload_token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_gpaorders_unloads_unloadtoken_with_http_info(self, unload_token : Annotated[StrictStr, Field(..., description="Unload token")], **kwargs):  # noqa: E501
        """Returns a specific GPA return  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gpaorders_unloads_unloadtoken_with_http_info(unload_token, async_req=True)
        >>> result = thread.get()

        :param unload_token: Unload token (required)
        :type unload_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GpaReturns, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'unload_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_gpaorders_unloads_unloadtoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['unload_token']:
            _path_params['unload_token'] = _params['unload_token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "GpaReturns",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/gpaorders/unloads/{unload_token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_gpaorders(self, body : Optional[GpaRequest] = None, **kwargs) -> GpaResponse:  # noqa: E501
        """Funds a user's GPA account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_gpaorders(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: GpaRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GpaResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_gpaorders_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_gpaorders_with_http_info(self, body : Optional[GpaRequest] = None, **kwargs):  # noqa: E501
        """Funds a user's GPA account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_gpaorders_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: GpaRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GpaResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_gpaorders" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "GpaResponse",
            '400': None,
            '409': None,
            '422': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/gpaorders', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_gpaorders_unloads(self, body : Optional[UnloadRequestModel] = None, **kwargs) -> GpaReturns:  # noqa: E501
        """Returns a GPA order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_gpaorders_unloads(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: UnloadRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GpaReturns
        """
        kwargs['_return_http_data_only'] = True
        return self.post_gpaorders_unloads_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_gpaorders_unloads_with_http_info(self, body : Optional[UnloadRequestModel] = None, **kwargs):  # noqa: E501
        """Returns a GPA order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_gpaorders_unloads_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: UnloadRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GpaReturns, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_gpaorders_unloads" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "GpaReturns",
            '400': None,
            '404': None,
            '412': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/gpaorders/unloads', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator
from marqeta_client.models.internal_account import InternalAccount
from marqeta_client.models.internal_authorization_transaction import InternalAuthorizationTransaction
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.internal_digital_wallet import InternalDigitalWallet
from marqeta_client.models.internal_gateway_log import InternalGatewayLog
from marqeta_client.models.internal_gpa_order import InternalGPAOrder
from marqeta_client.models.internal_user import InternalUser
from marqeta_client.models.transaction_model import TransactionModel

class FundingTranlog(BaseModel):
    """
    FundingTranlog
    """
    returned_balances: Optional[StrictStr] = Field(None, alias="returnedBalances")
    tags: Optional[StrictStr] = None
    transaction_type: StrictStr = Field(..., alias="transactionType")
    token: StrictStr = ...
    ref_transaction: Optional[InternalAuthorizationTransaction] = None
    node: StrictStr = ...
    network: StrictStr = ...
    sub_network: StrictStr = Field(..., alias="subNetwork")
    mid: Optional[StrictStr] = None
    tid: Optional[StrictStr] = None
    stan: Optional[StrictStr] = None
    ca_name: Optional[StrictStr] = None
    ca_street: Optional[StrictStr] = None
    ca_zip: Optional[StrictStr] = None
    ca_city: Optional[StrictStr] = None
    ca_region: Optional[StrictStr] = None
    ca_country: Optional[StrictStr] = None
    function_code: Optional[StrictStr] = Field(None, alias="functionCode")
    reason_code: Optional[StrictStr] = Field(None, alias="reasonCode")
    response_code: Optional[StrictStr] = Field(None, alias="responseCode")
    approval_number: Optional[StrictStr] = Field(None, alias="approvalNumber")
    display_message: Optional[StrictStr] = Field(None, alias="displayMessage")
    var_date: Optional[datetime] = Field(None, alias="date")
    transmission_date: Optional[datetime] = Field(None, alias="transmissionDate")
    local_transaction_date: Optional[datetime] = Field(None, alias="localTransactionDate")
    capture_date: Optional[datetime] = Field(None, alias="captureDate")
    settlement_date: Optional[datetime] = Field(None, alias="settlementDate")
    itc: Optional[StrictStr] = None
    irc: Optional[StrictStr] = None
    currency_code: Optional[StrictStr] = Field(None, alias="currencyCode")
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    additional_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="additionalAmount")
    acquirer_fee: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="acquirerFee")
    issuer_fee: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="issuerFee")
    rc: Optional[StrictStr] = None
    extrc: Optional[StrictStr] = None
    duration: Optional[StrictInt] = None
    cardholder: Optional[InternalUser] = None
    acting_cardholder: Optional[InternalUser] = Field(None, alias="actingCardholder")
    card: Optional[InternalCard] = None
    account: Optional[InternalAccount] = None
    account2: Optional[InternalAccount] = None
    mcc: Optional[StrictStr] = None
    network_reference_id: Optional[StrictStr] = Field(None, alias="networkReferenceId")
    acquirer_reference_id: Optional[StrictStr] = Field(None, alias="acquirerReferenceId")
    retrieval_reference_number: Optional[StrictStr] = Field(None, alias="retrievalReferenceNumber")
    forwarding_inst_id: Optional[StrictStr] = Field(None, alias="forwardingInstId")
    network_mid: Optional[StrictStr] = Field(None, alias="networkMid")
    request_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="requestAmount")
    transaction_state: Optional[StrictStr] = Field(None, alias="transactionState")
    remote_host: Optional[StrictStr] = Field(None, alias="remoteHost")
    response_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="responseAmount")
    expiration_time: Optional[datetime] = Field(None, alias="expirationTime")
    incoming_network_request_itc: Optional[StrictStr] = Field(None, alias="incomingNetworkRequestITC")
    digital_wallet_token: Optional[InternalDigitalWallet] = None
    tranlog_attributes: Optional[Dict[str, StrictStr]] = Field(None, alias="tranlogAttributes")
    payload: Optional[TransactionModel] = None
    layer: Optional[StrictInt] = None
    transaction_name: Optional[StrictStr] = None
    originator: Optional[StrictStr] = None
    acquirer: Optional[StrictStr] = None
    gpaorder: InternalGPAOrder = ...
    gateway_log: InternalGatewayLog = Field(..., alias="gatewayLog")
    __properties = ["returnedBalances", "tags", "transactionType", "token", "ref_transaction", "node", "network", "subNetwork", "mid", "tid", "stan", "ca_name", "ca_street", "ca_zip", "ca_city", "ca_region", "ca_country", "functionCode", "reasonCode", "responseCode", "approvalNumber", "displayMessage", "date", "transmissionDate", "localTransactionDate", "captureDate", "settlementDate", "itc", "irc", "currencyCode", "amount", "additionalAmount", "acquirerFee", "issuerFee", "rc", "extrc", "duration", "cardholder", "actingCardholder", "card", "account", "account2", "mcc", "networkReferenceId", "acquirerReferenceId", "retrievalReferenceNumber", "forwardingInstId", "networkMid", "requestAmount", "transactionState", "remoteHost", "responseAmount", "expirationTime", "incomingNetworkRequestITC", "digital_wallet_token", "tranlogAttributes", "payload", "layer", "transaction_name", "originator", "acquirer", "gpaorder", "gatewayLog"]

    @validator('transaction_state')
    def transaction_state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR', 'ALL'):
            raise ValueError("must be one of enum values ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR', 'ALL')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FundingTranlog:
        """Create an instance of FundingTranlog from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ref_transaction
        if self.ref_transaction:
            _dict['ref_transaction'] = self.ref_transaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cardholder
        if self.cardholder:
            _dict['cardholder'] = self.cardholder.to_dict()
        # override the default output from pydantic by calling `to_dict()` of acting_cardholder
        if self.acting_cardholder:
            _dict['actingCardholder'] = self.acting_cardholder.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of account2
        if self.account2:
            _dict['account2'] = self.account2.to_dict()
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token
        if self.digital_wallet_token:
            _dict['digital_wallet_token'] = self.digital_wallet_token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payload
        if self.payload:
            _dict['payload'] = self.payload.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gpaorder
        if self.gpaorder:
            _dict['gpaorder'] = self.gpaorder.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gateway_log
        if self.gateway_log:
            _dict['gatewayLog'] = self.gateway_log.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FundingTranlog:
        """Create an instance of FundingTranlog from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FundingTranlog.parse_obj(obj)

        _obj = FundingTranlog.parse_obj({
            "returned_balances": obj.get("returnedBalances"),
            "tags": obj.get("tags"),
            "transaction_type": obj.get("transactionType"),
            "token": obj.get("token"),
            "ref_transaction": InternalAuthorizationTransaction.from_dict(obj.get("ref_transaction")) if obj.get("ref_transaction") is not None else None,
            "node": obj.get("node"),
            "network": obj.get("network"),
            "sub_network": obj.get("subNetwork"),
            "mid": obj.get("mid"),
            "tid": obj.get("tid"),
            "stan": obj.get("stan"),
            "ca_name": obj.get("ca_name"),
            "ca_street": obj.get("ca_street"),
            "ca_zip": obj.get("ca_zip"),
            "ca_city": obj.get("ca_city"),
            "ca_region": obj.get("ca_region"),
            "ca_country": obj.get("ca_country"),
            "function_code": obj.get("functionCode"),
            "reason_code": obj.get("reasonCode"),
            "response_code": obj.get("responseCode"),
            "approval_number": obj.get("approvalNumber"),
            "display_message": obj.get("displayMessage"),
            "var_date": obj.get("date"),
            "transmission_date": obj.get("transmissionDate"),
            "local_transaction_date": obj.get("localTransactionDate"),
            "capture_date": obj.get("captureDate"),
            "settlement_date": obj.get("settlementDate"),
            "itc": obj.get("itc"),
            "irc": obj.get("irc"),
            "currency_code": obj.get("currencyCode"),
            "amount": obj.get("amount"),
            "additional_amount": obj.get("additionalAmount"),
            "acquirer_fee": obj.get("acquirerFee"),
            "issuer_fee": obj.get("issuerFee"),
            "rc": obj.get("rc"),
            "extrc": obj.get("extrc"),
            "duration": obj.get("duration"),
            "cardholder": InternalUser.from_dict(obj.get("cardholder")) if obj.get("cardholder") is not None else None,
            "acting_cardholder": InternalUser.from_dict(obj.get("actingCardholder")) if obj.get("actingCardholder") is not None else None,
            "card": InternalCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "account": InternalAccount.from_dict(obj.get("account")) if obj.get("account") is not None else None,
            "account2": InternalAccount.from_dict(obj.get("account2")) if obj.get("account2") is not None else None,
            "mcc": obj.get("mcc"),
            "network_reference_id": obj.get("networkReferenceId"),
            "acquirer_reference_id": obj.get("acquirerReferenceId"),
            "retrieval_reference_number": obj.get("retrievalReferenceNumber"),
            "forwarding_inst_id": obj.get("forwardingInstId"),
            "network_mid": obj.get("networkMid"),
            "request_amount": obj.get("requestAmount"),
            "transaction_state": obj.get("transactionState"),
            "remote_host": obj.get("remoteHost"),
            "response_amount": obj.get("responseAmount"),
            "expiration_time": obj.get("expirationTime"),
            "incoming_network_request_itc": obj.get("incomingNetworkRequestITC"),
            "digital_wallet_token": InternalDigitalWallet.from_dict(obj.get("digital_wallet_token")) if obj.get("digital_wallet_token") is not None else None,
            "tranlog_attributes": obj.get("tranlogAttributes"),
            "payload": TransactionModel.from_dict(obj.get("payload")) if obj.get("payload") is not None else None,
            "layer": obj.get("layer"),
            "transaction_name": obj.get("transaction_name"),
            "originator": obj.get("originator"),
            "acquirer": obj.get("acquirer"),
            "gpaorder": InternalGPAOrder.from_dict(obj.get("gpaorder")) if obj.get("gpaorder") is not None else None,
            "gateway_log": InternalGatewayLog.from_dict(obj.get("gatewayLog")) if obj.get("gatewayLog") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictStr

class DigitalWalletApplePayProvisionResponse(BaseModel):
    """
    DigitalWalletApplePayProvisionResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    card_token: StrictStr = ...
    encrypted_pass_data: StrictStr = ...
    activation_data: StrictStr = ...
    ephemeral_public_key: StrictStr = ...
    __properties = ["created_time", "last_modified_time", "card_token", "encrypted_pass_data", "activation_data", "ephemeral_public_key"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletApplePayProvisionResponse:
        """Create an instance of DigitalWalletApplePayProvisionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletApplePayProvisionResponse:
        """Create an instance of DigitalWalletApplePayProvisionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletApplePayProvisionResponse.parse_obj(obj)

        _obj = DigitalWalletApplePayProvisionResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "card_token": obj.get("card_token"),
            "encrypted_pass_data": obj.get("encrypted_pass_data"),
            "activation_data": obj.get("activation_data"),
            "ephemeral_public_key": obj.get("ephemeral_public_key")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist
from marqeta_client.models.gl_entry import GLEntry

class GlTransactionRequest(BaseModel):
    """
    GlTransactionRequest
    """
    entries: conlist(GLEntry) = ...
    detail: Optional[StrictStr] = None
    cardholder_visible: Optional[StrictBool] = None
    trigger_webhook: Optional[StrictBool] = None
    reference_transaction_token: Optional[StrictStr] = None
    __properties = ["entries", "detail", "cardholder_visible", "trigger_webhook", "reference_transaction_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GlTransactionRequest:
        """Create an instance of GlTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in entries (list)
        _items = []
        if self.entries:
            for _item in self.entries:
                if _item:
                    _items.append(_item.to_dict())
            _dict['entries'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GlTransactionRequest:
        """Create an instance of GlTransactionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GlTransactionRequest.parse_obj(obj)

        _obj = GlTransactionRequest.parse_obj({
            "entries": [GLEntry.from_dict(_item) for _item in obj.get("entries")] if obj.get("entries") is not None else None,
            "detail": obj.get("detail"),
            "cardholder_visible": obj.get("cardholder_visible"),
            "trigger_webhook": obj.get("trigger_webhook"),
            "reference_transaction_token": obj.get("reference_transaction_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt, StrictStr

class ClearingRetryModel(BaseModel):
    """
    ClearingRetryModel
    """
    original_failed_transaction_token: StrictStr = ...
    new_network_reference: Optional[StrictStr] = None
    new_approval_code: Optional[StrictStr] = None
    new_stan: Optional[StrictStr] = None
    find_original_window_days: Optional[StrictInt] = None
    new_processing_code: Optional[StrictStr] = None
    __properties = ["original_failed_transaction_token", "new_network_reference", "new_approval_code", "new_stan", "find_original_window_days", "new_processing_code"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClearingRetryModel:
        """Create an instance of ClearingRetryModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "new_approval_code",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClearingRetryModel:
        """Create an instance of ClearingRetryModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ClearingRetryModel.parse_obj(obj)

        _obj = ClearingRetryModel.parse_obj({
            "original_failed_transaction_token": obj.get("original_failed_transaction_token"),
            "new_network_reference": obj.get("new_network_reference"),
            "new_approval_code": obj.get("new_approval_code"),
            "new_stan": obj.get("new_stan"),
            "find_original_window_days": obj.get("find_original_window_days"),
            "new_processing_code": obj.get("new_processing_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.settlement_data import SettlementData

class Network(BaseModel):
    """
    Network
    """
    original_amount: Optional[Union[StrictFloat, StrictInt]] = None
    conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    original_currency_code: Optional[StrictStr] = None
    dynamic_currency_conversion: Optional[StrictBool] = False
    settlement_data: Optional[SettlementData] = None
    __properties = ["original_amount", "conversion_rate", "original_currency_code", "dynamic_currency_conversion", "settlement_data"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Network:
        """Create an instance of Network from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of settlement_data
        if self.settlement_data:
            _dict['settlement_data'] = self.settlement_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Network:
        """Create an instance of Network from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Network.parse_obj(obj)

        _obj = Network.parse_obj({
            "original_amount": obj.get("original_amount"),
            "conversion_rate": obj.get("conversion_rate"),
            "original_currency_code": obj.get("original_currency_code"),
            "dynamic_currency_conversion": obj.get("dynamic_currency_conversion") if obj.get("dynamic_currency_conversion") is not None else False,
            "settlement_data": SettlementData.from_dict(obj.get("settlement_data")) if obj.get("settlement_data") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr, conlist, validator
from marqeta_client.models.internal_authorization_transaction import InternalAuthorizationTransaction

class InternalFindOriginalRequest(BaseModel):
    """
    InternalFindOriginalRequest
    """
    authorization_tranlog: InternalAuthorizationTransaction = ...
    override_days: Optional[StrictInt] = None
    context: Optional[Dict[str, Dict[str, Any]]] = None
    configuration: Optional[Dict[str, StrictStr]] = None
    finders: Optional[conlist(StrictStr)] = None
    original_timestamp: Optional[datetime] = None
    original_stan: Optional[StrictStr] = None
    __properties = ["authorization_tranlog", "override_days", "context", "configuration", "finders", "original_timestamp", "original_stan"]

    @validator('finders')
    def finders_validate_enum(cls, v):
        if v is None:
            return v

        for i in v:
            if i not in ('AMOUNT_LOCAL_TXN_DATE', 'APPROVAL_CODE_RRN', 'APPROVAL_CODE_STAN', 'APPROVAL_CODE_STAN_LOCAL_TXN_DATE', 'APPROVAL_CODE_CARDHOLDER_AMOUNT', 'CHARGEBACK_NREF_', 'EXPIRABLE_AUTH_DIGEST', 'LOCAL_TXN_DATE_MID_AMOUNT', 'LOCAL_TXN_DATE_MID_AMOUNT_TIP', 'MOD_LOCAL_TXN_DATE_MID_AMOUNT_TIP', 'MOST_RECENT_CHARGEBACK_TXN', 'NRID_EXCEPT_PULSE', 'NRID', 'NULL_RESULT', 'PULSE_STAN_RRN', 'RRN_EXCEPT_PULSE', 'RRN', 'TXN_TOKEN'):
                raise ValueError("each list item must be one of ('AMOUNT_LOCAL_TXN_DATE', 'APPROVAL_CODE_RRN', 'APPROVAL_CODE_STAN', 'APPROVAL_CODE_STAN_LOCAL_TXN_DATE', 'APPROVAL_CODE_CARDHOLDER_AMOUNT', 'CHARGEBACK_NREF_', 'EXPIRABLE_AUTH_DIGEST', 'LOCAL_TXN_DATE_MID_AMOUNT', 'LOCAL_TXN_DATE_MID_AMOUNT_TIP', 'MOD_LOCAL_TXN_DATE_MID_AMOUNT_TIP', 'MOST_RECENT_CHARGEBACK_TXN', 'NRID_EXCEPT_PULSE', 'NRID', 'NULL_RESULT', 'PULSE_STAN_RRN', 'RRN_EXCEPT_PULSE', 'RRN', 'TXN_TOKEN')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalFindOriginalRequest:
        """Create an instance of InternalFindOriginalRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of authorization_tranlog
        if self.authorization_tranlog:
            _dict['authorization_tranlog'] = self.authorization_tranlog.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalFindOriginalRequest:
        """Create an instance of InternalFindOriginalRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalFindOriginalRequest.parse_obj(obj)

        _obj = InternalFindOriginalRequest.parse_obj({
            "authorization_tranlog": InternalAuthorizationTransaction.from_dict(obj.get("authorization_tranlog")) if obj.get("authorization_tranlog") is not None else None,
            "override_days": obj.get("override_days"),
            "context": obj.get("context"),
            "configuration": obj.get("configuration"),
            "finders": obj.get("finders"),
            "original_timestamp": obj.get("original_timestamp"),
            "original_stan": obj.get("original_stan")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, constr

class StoreResponseModel(BaseModel):
    """
    StoreResponseModel
    """
    name: constr(strict=True, max_length=40, min_length=0) = ...
    active: Optional[StrictBool] = True
    contact: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    contact_email: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    address1: constr(strict=True, max_length=255, min_length=0) = ...
    address2: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    city: constr(strict=True, max_length=40, min_length=0) = ...
    state: constr(strict=True, max_length=255, min_length=0) = ...
    province: Optional[constr(strict=True, max_length=20, min_length=0)] = None
    zip: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    postal_code: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    phone: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    country: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="The unique identifier of the merchant")
    partial_auth_flag: Optional[StrictBool] = Field(True, description="1 char max")
    mid: constr(strict=True, max_length=50, min_length=1) = ...
    network_mid: Optional[constr(strict=True, max_length=50, min_length=1)] = None
    merchant_token: constr(strict=True, max_length=36, min_length=0) = ...
    partial_approval_capable: Optional[StrictBool] = False
    keyed_auth_cvv_enforced: Optional[StrictBool] = False
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    __properties = ["name", "active", "contact", "contact_email", "longitude", "latitude", "address1", "address2", "city", "state", "province", "zip", "postal_code", "phone", "country", "token", "partial_auth_flag", "mid", "network_mid", "merchant_token", "partial_approval_capable", "keyed_auth_cvv_enforced", "created_time", "last_modified_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> StoreResponseModel:
        """Create an instance of StoreResponseModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> StoreResponseModel:
        """Create an instance of StoreResponseModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return StoreResponseModel.parse_obj(obj)

        _obj = StoreResponseModel.parse_obj({
            "name": obj.get("name"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "contact": obj.get("contact"),
            "contact_email": obj.get("contact_email"),
            "longitude": obj.get("longitude"),
            "latitude": obj.get("latitude"),
            "address1": obj.get("address1"),
            "address2": obj.get("address2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "province": obj.get("province"),
            "zip": obj.get("zip"),
            "postal_code": obj.get("postal_code"),
            "phone": obj.get("phone"),
            "country": obj.get("country"),
            "token": obj.get("token"),
            "partial_auth_flag": obj.get("partial_auth_flag") if obj.get("partial_auth_flag") is not None else True,
            "mid": obj.get("mid"),
            "network_mid": obj.get("network_mid"),
            "merchant_token": obj.get("merchant_token"),
            "partial_approval_capable": obj.get("partial_approval_capable") if obj.get("partial_approval_capable") is not None else False,
            "keyed_auth_cvv_enforced": obj.get("keyed_auth_cvv_enforced") if obj.get("keyed_auth_cvv_enforced") is not None else False,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictStr, confloat, conint, constr
from marqeta_client.models.ptc_soft_descriptor import PTCSoftDescriptor

class PushToCardDisburseRequest(BaseModel):
    """
    PushToCardDisburseRequest
    """
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    memo: Optional[constr(strict=True, max_length=99, min_length=1)] = None
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    currency_code: StrictStr = ...
    amount: Union[confloat(le=5E+4, ge=0.01, strict=True), conint(le=50000, ge=1, strict=True)] = ...
    payment_instrument_token: constr(strict=True, max_length=36, min_length=1) = ...
    soft_descriptor: Optional[PTCSoftDescriptor] = None
    __properties = ["tags", "memo", "token", "currency_code", "amount", "payment_instrument_token", "soft_descriptor"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PushToCardDisburseRequest:
        """Create an instance of PushToCardDisburseRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of soft_descriptor
        if self.soft_descriptor:
            _dict['soft_descriptor'] = self.soft_descriptor.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PushToCardDisburseRequest:
        """Create an instance of PushToCardDisburseRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PushToCardDisburseRequest.parse_obj(obj)

        _obj = PushToCardDisburseRequest.parse_obj({
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "token": obj.get("token"),
            "currency_code": obj.get("currency_code"),
            "amount": obj.get("amount"),
            "payment_instrument_token": obj.get("payment_instrument_token"),
            "soft_descriptor": PTCSoftDescriptor.from_dict(obj.get("soft_descriptor")) if obj.get("soft_descriptor") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class VelocityCache(BaseModel):
    """
    VelocityCache
    """
    card_holder_id: Optional[StrictInt] = Field(None, alias="cardHolderId")
    velocity_control_id: Optional[StrictInt] = Field(None, alias="velocityControlId")
    used_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="usedAmount")
    usage_count: Optional[StrictInt] = Field(None, alias="usageCount")
    max_id: Optional[StrictInt] = Field(None, alias="maxId")
    window_start_time: Optional[datetime] = Field(None, alias="windowStartTime")
    vc_signature: Optional[StrictStr] = Field(None, alias="vcSignature")
    created_time: Optional[datetime] = Field(None, alias="createdTime")
    last_modified_time: Optional[datetime] = Field(None, alias="lastModifiedTime")
    __properties = ["cardHolderId", "velocityControlId", "usedAmount", "usageCount", "maxId", "windowStartTime", "vcSignature", "createdTime", "lastModifiedTime"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VelocityCache:
        """Create an instance of VelocityCache from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VelocityCache:
        """Create an instance of VelocityCache from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return VelocityCache.parse_obj(obj)

        _obj = VelocityCache.parse_obj({
            "card_holder_id": obj.get("cardHolderId"),
            "velocity_control_id": obj.get("velocityControlId"),
            "used_amount": obj.get("usedAmount"),
            "usage_count": obj.get("usageCount"),
            "max_id": obj.get("maxId"),
            "window_start_time": obj.get("windowStartTime"),
            "vc_signature": obj.get("vcSignature"),
            "created_time": obj.get("createdTime"),
            "last_modified_time": obj.get("lastModifiedTime")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, conlist, constr
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.transaction_options import TransactionOptions
from marqeta_client.models.webhook import Webhook

class AuthorizationAdviceModel(BaseModel):
    """
    AuthorizationAdviceModel
    """
    amount: Union[StrictFloat, StrictInt] = ...
    network_fees: Optional[conlist(NetworkFeeModel)] = None
    webhook: Optional[Webhook] = None
    original_transaction_token: constr(strict=True, max_length=36, min_length=1) = ...
    transaction_options: Optional[TransactionOptions] = None
    __properties = ["amount", "network_fees", "webhook", "original_transaction_token", "transaction_options"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuthorizationAdviceModel:
        """Create an instance of AuthorizationAdviceModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in network_fees (list)
        _items = []
        if self.network_fees:
            for _item in self.network_fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction_options
        if self.transaction_options:
            _dict['transaction_options'] = self.transaction_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuthorizationAdviceModel:
        """Create an instance of AuthorizationAdviceModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AuthorizationAdviceModel.parse_obj(obj)

        _obj = AuthorizationAdviceModel.parse_obj({
            "amount": obj.get("amount"),
            "network_fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("network_fees")] if obj.get("network_fees") is not None else None,
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None,
            "original_transaction_token": obj.get("original_transaction_token"),
            "transaction_options": TransactionOptions.from_dict(obj.get("transaction_options")) if obj.get("transaction_options") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr, validator

class DepositDepositResponse(BaseModel):
    """
    DepositDepositResponse
    """
    token: Optional[StrictStr] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    type: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    settlement_date: Optional[datetime] = None
    state_reason: Optional[StrictStr] = None
    state_reason_code: Optional[StrictStr] = None
    direct_deposit_account_token: Optional[StrictStr] = None
    user_token: Optional[StrictStr] = None
    business_token: Optional[StrictStr] = None
    created_time: Optional[datetime] = None
    last_modified_time: Optional[datetime] = None
    standard_entry_class_code: Optional[StrictStr] = None
    company_name: Optional[StrictStr] = None
    company_discretionary_data: Optional[StrictStr] = None
    company_identification: Optional[StrictStr] = None
    company_entry_description: Optional[StrictStr] = None
    individual_identification_number: Optional[StrictStr] = None
    individual_name: Optional[StrictStr] = None
    __properties = ["token", "amount", "type", "state", "settlement_date", "state_reason", "state_reason_code", "direct_deposit_account_token", "user_token", "business_token", "created_time", "last_modified_time", "standard_entry_class_code", "company_name", "company_discretionary_data", "company_identification", "company_entry_description", "individual_identification_number", "individual_name"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CREDIT', 'DEBIT'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'APPLIED', 'REVERSED', 'REJECTED'):
            raise ValueError("must be one of enum values ('PENDING', 'APPLIED', 'REVERSED', 'REJECTED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DepositDepositResponse:
        """Create an instance of DepositDepositResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DepositDepositResponse:
        """Create an instance of DepositDepositResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DepositDepositResponse.parse_obj(obj)

        _obj = DepositDepositResponse.parse_obj({
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "type": obj.get("type"),
            "state": obj.get("state"),
            "settlement_date": obj.get("settlement_date"),
            "state_reason": obj.get("state_reason"),
            "state_reason_code": obj.get("state_reason_code"),
            "direct_deposit_account_token": obj.get("direct_deposit_account_token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "standard_entry_class_code": obj.get("standard_entry_class_code"),
            "company_name": obj.get("company_name"),
            "company_discretionary_data": obj.get("company_discretionary_data"),
            "company_identification": obj.get("company_identification"),
            "company_entry_description": obj.get("company_entry_description"),
            "individual_identification_number": obj.get("individual_identification_number"),
            "individual_name": obj.get("individual_name")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictStr, confloat, conint, constr, validator

class BankTransferRequestModel(BaseModel):
    """
    BankTransferRequestModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    amount: Union[confloat(ge=0.01, strict=True), conint(ge=1, strict=True)] = ...
    memo: Optional[StrictStr] = None
    channel: Optional[StrictStr] = Field(None, description="default = API")
    funding_source_token: constr(strict=True, max_length=36, min_length=0) = ...
    type: StrictStr = ...
    statement_descriptor: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    currency_code: Optional[StrictStr] = Field(None, description="default = USD")
    transfer_speed: Optional[StrictStr] = Field(None, description="default = STANDARD")
    standard_entry_class_code: Optional[StrictStr] = None
    created_by: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    __properties = ["token", "amount", "memo", "channel", "funding_source_token", "type", "statement_descriptor", "currency_code", "transfer_speed", "standard_entry_class_code", "created_by"]

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('API', 'SYSTEM', 'ADMIN'):
            raise ValueError("must be one of enum values ('API', 'SYSTEM', 'ADMIN')")
        return v

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('PUSH', 'PULL'):
            raise ValueError("must be one of enum values ('PUSH', 'PULL')")
        return v

    @validator('transfer_speed')
    def transfer_speed_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('STANDARD', 'SAME_DAY'):
            raise ValueError("must be one of enum values ('STANDARD', 'SAME_DAY')")
        return v

    @validator('standard_entry_class_code')
    def standard_entry_class_code_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('WEB', 'PPD', 'CCD'):
            raise ValueError("must be one of enum values ('WEB', 'PPD', 'CCD')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BankTransferRequestModel:
        """Create an instance of BankTransferRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BankTransferRequestModel:
        """Create an instance of BankTransferRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BankTransferRequestModel.parse_obj(obj)

        _obj = BankTransferRequestModel.parse_obj({
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "memo": obj.get("memo"),
            "channel": obj.get("channel"),
            "funding_source_token": obj.get("funding_source_token"),
            "type": obj.get("type"),
            "statement_descriptor": obj.get("statement_descriptor"),
            "currency_code": obj.get("currency_code"),
            "transfer_speed": obj.get("transfer_speed"),
            "standard_entry_class_code": obj.get("standard_entry_class_code"),
            "created_by": obj.get("created_by")
        })
        return _obj

